@@ -68,4 +68,8 @@ class Payment:
         # dateTo
         # site
         r = requests.get(self.url + '/payments',params=filters, headers=self.headers)
+        return r.json()
+
+    def refund(self,payment_id:str):
+        r = requests.post(self.url + '/payments/{}/refunds'.format(payment_id), headers=self.headers)
         return r.json()
\ No newline at end of file
